function compute_means(category)
%this function creates the .DAT files that contain the mean values of ERP
%category indicates the group name: 'OCD', 'Controls' e.t.c.


%enter the appropriate location
dirname = ['C:\Matlab\work\DATA\' category];
cd (dirname);

%in each directory there must exist an appropriate text file
%containing the code names of the category's subjects
patient_list = [category '.txt'];
f=fopen(patient_list,'rt');
if f==-1
   error('The file does not exist');
end

%the below matrix shows the times of the procedure
%that a low frequency was used
lowset = [3 6 8 9 10 12 15 16 18 19  21 23 25];

TEMPA=(0:2:1022)';

%the three matrices that will be created for
%Low, High and Mean data values
LAMP(:,2) = TEMPA;
HAMP(:,2) = TEMPA;
TAMP(:,2) = TEMPA;

code=fgetl(f);
%BEGIN loop for each patient
while code ~=-1,
    if ~isempty(code),
        fprintf('%s\n',code);
    end
    dirn = [dirname,'\',code];
    cd(dirn);
    %begin loop for each node
    disp('=======================');
    for l=2:16
        strl = int2str(l);
        try
            LAMP(1:512,1)=0;
            HAMP(1:512,1)=0;
            TAMP(1:512,1)=0;
            if l<10
                AMP=load([code,'0',char(48+l)]);
            else
                AMP=load([code,'1',char(38+l)]);
            end
            
            %unfortunately some values are in a different scale
            %voltages are now converted to microvolts (vots)
            if max(AMP)>100 | min(AMP)<-100
                AMP = AMP/100;
            end
            
            siz = length(AMP)/512;
            tmstr = ['lead ', strl];
            disp(tmstr);
            i = 0;
            li = 0;
            hi = 0;
            
            %the below takes under consideration the missing values and polarity
            %missing values are identified by all the group values (512) being zero
            %if the value is above 81 or below -81 it should be excluded due to polarity
            %for every group of data the number of such excluded values is calculated
            %if their number is above 256 the whole group is excluded. if it isn't the excluded
            %values are replaced by the mean of the valid values of the group.
            while i < siz
                i = i + 1;
                if isempty(intersect(i,lowset)) == 0
                    if any(AMP(1+(i-1)*512:512+(i-1)*512))~=0 & all(AMP(1+(i-1)*512:512+(i-1)*512))<81 & all(AMP(1+(i-1)*512:512+(i-1)*512))>-81
                        LAMP(:,1) = LAMP(:,1) + AMP(1+(i-1)*512:512+(i-1)*512);
                        li = li + 1;
                    elseif any(AMP(1+(i-1)*512:512+(i-1)*512))~=0 & any(AMP(1+(i-1)*512:512+(i-1)*512))>=81 | any(AMP(1+(i-1)*512:512+(i-1)*512))<=-81
                        z = 0;
                        for j=1:512
                            if AMP(j+(i-1)*512)<=-81 | AMP(j+(i-1)*512)>=81
                                AMP(j+(i-1)*512) = 0;
                                z = z + 1;
                                TempArr(z) = j
                            end
                        end
                        if z < 256
                            tempmean = SUM(AMP(1+(i-1)*512:512+(i-1)*512))/(512-z)
                            for j=1:512
                                if isempty(intersect(j,TempArr)) == 0
                                    AMP(j+(i-1)*512) = tempmean;
                                end
                            end
                            LAMP(:,1) = LAMP(:,1) + AMP(1+(i-1)*512:512+(i-1)*512);
                            li = li + 1;
                        end
                        clear TempArr tempmean;
                    end
                else
                    if any(AMP(1+(i-1)*512:512+(i-1)*512))~=0 & all(AMP(1+(i-1)*512:512+(i-1)*512))<81 & all(AMP(1+(i-1)*512:512+(i-1)*512))>-81
                        HAMP(:,1) = HAMP(:,1) + AMP(1+(i-1)*512:512+(i-1)*512);
                        hi = hi + 1;
                    elseif any(AMP(1+(i-1)*512:512+(i-1)*512))~=0 & any(AMP(1+(i-1)*512:512+(i-1)*512))>=81 | any(AMP(1+(i-1)*512:512+(i-1)*512))<=-81
                        z = 0;
                        for j=1:512
                            if AMP(j+(i-1)*512)<=-81 | AMP(j+(i-1)*512)>=81
                                AMP(j+(i-1)*512) = 0;
                                z = z + 1;
                                TempArr(z) = j
                            end
                        end
                        if z < 256
                            tempmean = SUM(AMP(1+(i-1)*512:512+(i-1)*512))/(512-z)
                            for j=1:512
                                if isempty(intersect(j,TempArr)) == 0
                                    AMP(j+(i-1)*512) = tempmean;
                                end
                            end
                            HAMP(:,1) = HAMP(:,1) + AMP(1+(i-1)*512:512+(i-1)*512);
                            hi = hi + 1;
                        end
                        clear TempArr tempmean;
                    end
                end
            end
            templ = LAMP(1,1)/li;
            temph = HAMP(1,1)/hi;
            for i=1:512
                LAMP(i,1) = LAMP(i,1)/li - templ;
                HAMP(i,1) = HAMP(i,1)/hi - temph;
            end
            TAMP(:,1) = (LAMP(:,1) + HAMP(:,1))/2;
            
            %directory and file name generation
            if l<10
               tmgen = ['Z',code,'_0',char(48+l)];
            else
               tmgen = ['Z',code,'_1',char(38+l)];
            end
            try
                cd ('Low-Means')
            catch
                mkdir('Low-Means');
                cd ('Low-Means')
            end
            tmst = [tmgen, '-low.dat'];
            save (tmst, 'LAMP', '-ASCII', '-double', '-tabs');
            cd(dirn);
            try
                cd ('High-Means')
            catch
                mkdir('High-Means');
                cd ('High-Means')
            end
            tmst = [tmgen, '-high.dat'];
            save (tmst, 'HAMP', '-ASCII', '-double', '-tabs');
            cd(dirn);
            try
                cd ('General-Means')
            catch
                mkdir('General-Means');
                cd ('General-Means')
            end
            tmst = [tmgen, '.dat'];
            save (tmst, 'TAMP', '-ASCII', '-double', '-tabs');
            cd(dirn);
        catch
            tmstr = ['Missing Data - lead ' strl];
            disp(tmstr);
        end
   %end loop for each node
    end
    disp('------------------------------')
    disp('on with the next');
    disp('------------------------------')
    code=fgetl(f);
%END of loop for each patient
end
fclose(f);